self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "0c61e902085bc716345125fc73755ec5",
    "url": "/index.html"
  },
  {
    "revision": "3050908782a1f0d4f280",
    "url": "/static/css/2.5a2f7233.chunk.css"
  },
  {
    "revision": "c4095fd13b0915b6c795",
    "url": "/static/css/main.adb9c03c.chunk.css"
  },
  {
    "revision": "3050908782a1f0d4f280",
    "url": "/static/js/2.4dd24e80.chunk.js"
  },
  {
    "revision": "5002026598ed5d61cd3d68aaaa6f8e02",
    "url": "/static/js/2.4dd24e80.chunk.js.LICENSE.txt"
  },
  {
    "revision": "c4095fd13b0915b6c795",
    "url": "/static/js/main.bc16927b.chunk.js"
  },
  {
    "revision": "b5105b2d39e05584e697",
    "url": "/static/js/runtime-main.460b34f2.js"
  },
  {
    "revision": "42cf9f0820d16f3ac2c26a7710ce70f2",
    "url": "/static/media/Poppins-Black.42cf9f08.ttf"
  },
  {
    "revision": "c23534acbeddbaadfd0ab2d2bbfdfc84",
    "url": "/static/media/Poppins-Bold.c23534ac.ttf"
  },
  {
    "revision": "89c81a3cbc00c32cbe1b28561029be0d",
    "url": "/static/media/Poppins-Italic.89c81a3c.ttf"
  },
  {
    "revision": "2a47a29ceb33c966c8d79f8d5a5ea448",
    "url": "/static/media/Poppins-Light.2a47a29c.ttf"
  },
  {
    "revision": "41e8dead03fb979ecc23b8dfb0fef627",
    "url": "/static/media/Poppins-Regular.41e8dead.ttf"
  },
  {
    "revision": "7f31569e0fbd1497be2605ee1e2d2308",
    "url": "/static/media/arrow-down.7f31569e.svg"
  },
  {
    "revision": "bc7cab5379b8f4d23770ad9d4e058d12",
    "url": "/static/media/arrow-right.bc7cab53.svg"
  },
  {
    "revision": "d12c4d18ef04826528ce52c0642f72aa",
    "url": "/static/media/features.d12c4d18.svg"
  },
  {
    "revision": "6572136db09bcf52c0ef2f8b5f55cbbd",
    "url": "/static/media/help.6572136d.svg"
  },
  {
    "revision": "c57b1fe1e98fbd43c540da355b9f8471",
    "url": "/static/media/menu.c57b1fe1.svg"
  },
  {
    "revision": "9ee7f2835a38da32ed48ee3ffa4feb35",
    "url": "/static/media/minotaur.9ee7f283.svg"
  },
  {
    "revision": "17bec4b014b0da5725c6ed27d744fd82",
    "url": "/static/media/prediction.17bec4b0.svg"
  },
  {
    "revision": "42f6747b86a2f0a3a05bef969c9c265e",
    "url": "/static/media/search.42f6747b.svg"
  }
]);